==> freecad_0.11.4446-dfsg.orig.tar.gz: FreeCAD-0.11.4446/src/Mod/Points/Gui/Resources/translations/Points_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdPointsExport</name>
    <message>
      <location/>
      <source>Points</source>
      <translation>Točke</translation>
    </message>
    <message>
      <location/>
      <source>Export points...</source>
      <translation>Izvezi točke...</translation>
    </message>
    <message>
      <location/>
      <source>Exports a point cloud</source>
      <translation>prenesi pokazni oblak </translation>
    </message>
  </context>
  <context>
    <name>CmdPointsImport</name>
    <message>
      <location/>
      <source>Points</source>
      <translation>Točke</translation>
    </message>
    <message>
      <location/>
      <source>Import points...</source>
      <translation>Uvezi točke...</translation>
    </message>
    <message>
      <location/>
      <source>Imports a point cloud</source>
      <translation>prenesi pokazni oblak</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsPolyCut</name>
    <message>
      <location/>
      <source>Points</source>
      <translation>Točke</translation>
    </message>
    <message>
      <location/>
      <source>Cut point cloud</source>
      <translation>odreži pokazni oblak</translation>
    </message>
    <message>
      <location/>
      <source>Cuts a point cloud with a picked polygon</source>
      <translation>Izreže pokazni oblak s bere poligona</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsTransform</name>
    <message>
      <location/>
      <source>Points</source>
      <translation>Točke</translation>
    </message>
    <message>
      <location/>
      <source>Transform Points</source>
      <translation>Promijeni točke</translation>
    </message>
    <message>
      <location/>
      <source>Test to transform a point cloud</source>
      <translation>Test za pretvaranje pokaznog oblaka</translation>
    </message>
  </context>
  <context>
    <name>PointsGui::DlgPointsRead</name>
    <message>
      <location/>
      <source>ASCII points import</source>
      <translation>ASCII uvoz bodova</translation>
    </message>
    <message>
      <location/>
      <source>Template:</source>
      <translation>Predložak:</translation>
    </message>
    <message>
      <location/>
      <source>Special lines</source>
      <translation>Posebne linije</translation>
    </message>
    <message>
      <location/>
      <source>First line:</source>
      <translation>Prva linija:</translation>
    </message>
    <message>
      <location/>
      <source>Ignore</source>
      <translation>Zanemari</translation>
    </message>
    <message>
      <location/>
      <source>Cluster by lines starting with:</source>
      <translation>Klaster linijama koje počinju sa:</translation>
    </message>
    <message>
      <location/>
      <source>Ignore lines starting with:</source>
      <translation>Zanemari linije koje počinju sa:</translation>
    </message>
    <message>
      <location/>
      <source>Point format</source>
      <translation>Point format</translation>
    </message>
    <message>
      <location/>
      <source>Number separator:</source>
      <translation>Broj seperatora:</translation>
    </message>
    <message>
      <location/>
      <source>Points format:</source>
      <translation>Bodovi formata:</translation>
    </message>
    <message>
      <location/>
      <source>Next block:</source>
      <translation>Sljedeći blok:</translation>
    </message>
    <message>
      <location/>
      <source>,</source>
      <translation>,</translation>
    </message>
    <message>
      <location/>
      <source>;</source>
      <translation>;</translation>
    </message>
    <message>
      <location/>
      <source>\t</source>
      <translation>\t</translation>
    </message>
    <message>
      <location/>
      <source>\w</source>
      <translation>\w</translation>
    </message>
    <message>
      <location/>
      <source>X,Y,Z</source>
      <translation>X,Y,Z</translation>
    </message>
    <message>
      <location/>
      <source>X,Y</source>
      <translation>X,Y</translation>
    </message>
    <message>
      <location/>
      <source>none</source>
      <translation>nijedan</translation>
    </message>
    <message>
      <location/>
      <source>I,J,K (normal vector)</source>
      <translation>I,J,K (vektor normale)</translation>
    </message>
    <message>
      <location/>
      <source>I,K (normal vector 2D)</source>
      <translation>I,K (vektor normale 2D)</translation>
    </message>
    <message>
      <location/>
      <source>R,G,B (color)</source>
      <translation>R,G,B (u boji)</translation>
    </message>
    <message>
      <location/>
      <source>I (Gray value)</source>
      <translation>I (vrijednosti u sivim tonovima)</translation>
    </message>
    <message>
      <location/>
      <source>Preview</source>
      <translation>Pregled</translation>
    </message>
    <message>
      <location/>
      <source>100</source>
      <translation>100</translation>
    </message>
    <message>
      <location/>
      <source>Number of points</source>
      <translation>Broj točaka</translation>
    </message>
    <message>
      <location/>
      <source>Number of previewed lines:</source>
      <translation>Broj pregledanih linija:</translation>
    </message>
  </context>
  <context>
    <name>PointsGui::Workbench</name>
    <message>
      <location/>
      <source>Points tools</source>
      <translation>Alati točaka</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Points</source>
      <translation>&amp;Točke</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location/>
      <source>Ascii Points (*.asc);;All Files (*.*)</source>
      <translation>Ascii točke (*.asc);;Sve datoteke (*.*)</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location/>
      <source>Points tools</source>
      <translation>Alati točaka</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Points</source>
      <translation>&amp;Točke</translation>
    </message>
  </context>
</TS>

==> freecad_0.12.5284-dfsg.orig.tar.gz: FreeCAD-0.12.5284/src/Mod/Points/Gui/Resources/translations/Points_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdPointsExport</name>
    <message>
      <location filename="../../Command.cpp" line="+104"/>
      <source>Points</source>
      <translation>Točke</translation>
    </message>
    <message>
      <source>Export points...</source>
      <translation>Izvezi točke...</translation>
    </message>
    <message>
      <source>Exports a point cloud</source>
      <translation>prenesi pokazni oblak </translation>
    </message>
  </context>
  <context>
    <name>CmdPointsImport</name>
    <message>
      <source>Points</source>
      <translation>Točke</translation>
    </message>
    <message>
      <source>Import points...</source>
      <translation>Uvezi točke...</translation>
    </message>
    <message>
      <source>Imports a point cloud</source>
      <translation>prenesi pokazni oblak</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsPolyCut</name>
    <message>
      <source>Points</source>
      <translation>Točke</translation>
    </message>
    <message>
      <source>Cut point cloud</source>
      <translation>odreži pokazni oblak</translation>
    </message>
    <message>
      <source>Cuts a point cloud with a picked polygon</source>
      <translation>Izreže pokazni oblak s bere poligona</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsTransform</name>
    <message>
      <source>Points</source>
      <translation>Točke</translation>
    </message>
    <message>
      <source>Transform Points</source>
      <translation>Promijeni točke</translation>
    </message>
    <message>
      <source>Test to transform a point cloud</source>
      <translation>Test za pretvaranje pokaznog oblaka</translation>
    </message>
  </context>
  <context>
    <name>PointsGui::DlgPointsRead</name>
    <message>
      <location filename="../../DlgPointsRead.ui" line="+14"/>
      <source>ASCII points import</source>
      <translation>ASCII uvoz bodova</translation>
    </message>
    <message>
      <source>Template:</source>
      <translation>Predložak:</translation>
    </message>
    <message>
      <source>Special lines</source>
      <translation>Posebne linije</translation>
    </message>
    <message>
      <source>First line:</source>
      <translation>Prva linija:</translation>
    </message>
    <message>
      <source>Ignore</source>
      <translation>Zanemari</translation>
    </message>
    <message>
      <source>Cluster by lines starting with:</source>
      <translation>Klaster linijama koje počinju sa:</translation>
    </message>
    <message>
      <source>Ignore lines starting with:</source>
      <translation>Zanemari linije koje počinju sa:</translation>
    </message>
    <message>
      <source>Point format</source>
      <translation>Point format</translation>
    </message>
    <message>
      <source>Number separator:</source>
      <translation>Broj separatora:</translation>
    </message>
    <message>
      <source>Points format:</source>
      <translation>Bodovi formata:</translation>
    </message>
    <message>
      <source>Next block:</source>
      <translation>Sljedeći blok:</translation>
    </message>
    <message>
      <source>,</source>
      <translation>,</translation>
    </message>
    <message>
      <source>;</source>
      <translation>;</translation>
    </message>
    <message>
      <source>\t</source>
      <translation>\t</translation>
    </message>
    <message>
      <source>\w</source>
      <translation>\w</translation>
    </message>
    <message>
      <source>X,Y,Z</source>
      <translation>X,Y,Z</translation>
    </message>
    <message>
      <source>X,Y</source>
      <translation>X,Y</translation>
    </message>
    <message>
      <source>none</source>
      <translation>nijedan</translation>
    </message>
    <message>
      <source>I,J,K (normal vector)</source>
      <translation>I,J,K (vektor normale)</translation>
    </message>
    <message>
      <source>I,K (normal vector 2D)</source>
      <translation>I,K (vektor normale 2D)</translation>
    </message>
    <message>
      <source>R,G,B (color)</source>
      <translation>R,G,B (u boji)</translation>
    </message>
    <message>
      <source>I (Gray value)</source>
      <translation>I (vrijednosti u sivim tonovima)</translation>
    </message>
    <message>
      <source>Preview</source>
      <translation>Pregled</translation>
    </message>
    <message>
      <source>100</source>
      <translation>100</translation>
    </message>
    <message>
      <source>Number of points</source>
      <translation>Broj točaka</translation>
    </message>
    <message>
      <source>Number of previewed lines:</source>
      <translation>Broj pregledanih linija:</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="-84"/>
      <source>Ascii Points (*.asc);;All Files (*.*)</source>
      <translation>Ascii točke (*.asc);;Sve datoteke (*.*)</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Points tools</source>
      <translation>Alati točaka</translation>
    </message>
    <message>
      <source>&amp;Points</source>
      <translation>&amp;Točke</translation>
    </message>
  </context>
</TS>
